==> tlmpsql-1.4.src.tar.gz: tlmpsql-1.4/query.cc <==
#include <stdio.h>
#include <stdarg.h>
#include "/usr/include/mysql/mysql.h"
#include "tlmpsql.h"
#include "tlmplib.h"
#include "tlmpsql.m"

void _F_sql_query::dostart(int )
{
}
void _F_sql_query::doend()
{
}
void _F_sql_query::empty()
{
}
void _F_sql_query::onerow(MYSQL_ROW, int)
{
}

static int sql_query (_F_sql_query &c, NSQL &sq, const char *ctl, va_list list)
{
	int ret = sq.vqueryf (ctl,list);
	if (ret != -1){
		MYSQL_RES *res = sq.store_result();
		int nb = mysql_num_rows(res);
		if (nb == 0){
			c.empty();
		}else if (nb > 0){
			c.dostart(nb);
			for (int i=0; i<nb; i++){
				MYSQL_ROW row = mysql_fetch_row(res);
				c.onerow (row,i);
			}
			c.doend();
		}
		sq.free_result(res);
	}
	return ret;
}


int sql_query (_F_sql_query &c, NSQL &sq, const char *ctl, ...)
{
	va_list list;
	va_start (list,ctl);
	int ret = sql_query (c,sq,ctl,list);
	va_end (list);
	return ret;
}

static int sql_action (NSQL &sq, const char *ctl, va_list list)
{
	return sq.a_vqueryf (ctl,list);
}


int sql_action (NSQL &sq, const char *ctl, ...)
{
	va_list list;
	va_start (list,ctl);
	int ret = sql_action (sq,ctl,list);
	va_end (list);
	return ret;
}

static NSQL *default_sq = NULL;

int sql_query (_F_sql_query &c, const char *ctl, ...)
{
	int ret = -1;
	if (default_sq == NULL){
		tlmp_error (MSG_U(E_NODEFSQ,"sql_query: query_setdefautdb() was not called\n"));
	}else{
		va_list list;
		va_start (list,ctl);
		ret = sql_query (c,*default_sq,ctl,list);
		va_end (list);
	}
	return ret;
}

int sql_action (const char *ctl, ...)
{
	int ret = -1;
	if (default_sq == NULL){
		tlmp_error (MSG_R(E_NODEFSQ));
	}else{
		va_list list;
		va_start (list,ctl);
		ret = sql_action (*default_sq,ctl,list);
		va_end (list);
	}
	return ret;
}

/*
	Record the default database to use for sql_query
*/
void query_setdefaultdb(const char *server, const char *db)
{
	delete default_sq;
	default_sq = new NSQL (server,db);
}
/*
	Return the default database in use
*/
NSQL *query_getdefaultdb()
{
	return default_sq;
}

==> tlmpsql-1.5.src.tar.gz: tlmpsql-1.5/query.cc <==
#include <stdio.h>
#include <stdarg.h>
#include "/usr/include/mysql/mysql.h"
#include "tlmpsql.h"
#include "tlmplib.h"
#include "tlmpsql.m"

void _F_sql_query::dostart(int )
{
}
void _F_sql_query::doend()
{
}
void _F_sql_query::empty()
{
}
void _F_sql_query::onerow(const char *[],int, NSQL_FIELD_NAMES &fields)
{
}

static int sql_query (_F_sql_query &c, NSQL &sq, const char *ctl, va_list list)
{
	int ret = sq.vqueryf (ctl,list);
	if (ret != -1){
		MYSQL_RES *res = sq.store_result();
		int nb = mysql_num_rows(res);
		if (nb == 0){
			c.empty();
		}else if (nb > 0){
			c.dostart(nb);
			MYSQL_FIELD *mfields= mysql_fetch_fields(res);
			int numf = mysql_num_fields(res);
			const char *tbf[numf];
			for (int i=0; i<numf; i++) tbf[i] = mfields[i].name;
			NSQL_FIELD_NAMES fields (numf,tbf);
			for (int i=0; i<nb; i++){
				MYSQL_ROW row = mysql_fetch_row(res);
				c.onerow ((const char **)row,i,fields);
			}
			c.doend();
		}
		sq.free_result(res);
		ret = nb;
	}
	return ret;
}


/*
	Perform an SQL query, return the number of rows fetched or -1 if any error.
*/
int sql_query (_F_sql_query &c, NSQL &sq, const char *ctl, ...)
{
	va_list list;
	va_start (list,ctl);
	int ret = sql_query (c,sq,ctl,list);
	va_end (list);
	return ret;
}

static int sql_action (NSQL &sq, const char *ctl, va_list list)
{
	return sq.a_vqueryf (ctl,list);
}


int sql_action (NSQL &sq, const char *ctl, ...)
{
	va_list list;
	va_start (list,ctl);
	int ret = sql_action (sq,ctl,list);
	va_end (list);
	return ret;
}

static NSQL *default_sq = NULL;

/*
	Perform an SQL query, return the number of rows fetched or -1 if any error.
*/
int sql_query (_F_sql_query &c, const char *ctl, ...)
{
	int ret = -1;
	if (default_sq == NULL){
		tlmp_error (MSG_U(E_NODEFSQ,"sql_query: query_setdefautdb() was not called\n"));
	}else{
		va_list list;
		va_start (list,ctl);
		ret = sql_query (c,*default_sq,ctl,list);
		va_end (list);
	}
	return ret;
}

int sql_action (const char *ctl, ...)
{
	int ret = -1;
	if (default_sq == NULL){
		tlmp_error (MSG_R(E_NODEFSQ));
	}else{
		va_list list;
		va_start (list,ctl);
		ret = sql_action (*default_sq,ctl,list);
		va_end (list);
	}
	return ret;
}

/*
	Record the default database to use for sql_query
*/
void query_setdefaultdb(const char *server, const char *db)
{
	delete default_sq;
	default_sq = new NSQL (server,db);
}
/*
	Return the default database in use
*/
NSQL *query_getdefaultdb()
{
	return default_sq;
}
